changeset 34912:3f8886645ebd

Order colour names alphabetically / better match W3 list. Patch by Federico Kereki, fkereki gmail
author cehoyos
date Sun, 24 Jun 2012 12:17:03 +0000
parents dfce873c5225
children 69fe59abe044
files sub/subassconvert.c
diffstat 1 files changed, 18 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/sub/subassconvert.c	Fri Jun 22 20:07:15 2012 +0000
+++ b/sub/subassconvert.c	Sun Jun 24 12:17:03 2012 +0000
@@ -93,13 +93,24 @@
     const char *s;
     uint32_t v;
 } subrip_web_colors[] = {
-    /* 16 named HTML colors in BGR format */
-    {"red",     0x0000ff}, {"blue",   0xff0000}, {"lime",   0x00ff00},
-    {"aqua",    0xffff00}, {"purple", 0x800080}, {"yellow", 0x00ffff},
-    {"fuchsia", 0xff00ff}, {"white",  0xffffff}, {"gray",   0x808080},
-    {"maroon",  0x000080}, {"olive",  0x008080}, {"black",  0x000000},
-    {"silver",  0xc0c0c0}, {"teal",   0x808000}, {"green",  0x008000},
-    {"navy",    0x800000}
+    /* Named CSS3 colors in BGR format; a subset of those
+       at http://www.w3.org/TR/css3-color/#svg-color */
+    {"aqua",    0xffff00},
+    {"black",   0x000000},
+    {"blue",    0xff0000},
+    {"fuchsia", 0xff00ff},
+    {"gray",    0x808080},
+    {"green",   0x008000},
+    {"lime",    0x00ff00},
+    {"maroon",  0x000080},
+    {"navy",    0x800000},
+    {"olive",   0x008080},
+    {"purple",  0x800080},
+    {"red",     0x0000ff},
+    {"silver",  0xc0c0c0},
+    {"teal",    0x808000},
+    {"white",   0xffffff},
+    {"yellow",  0x00ffff},
 };
 
 #define SUBRIP_MAX_STACKED_FONT_TAGS    16